@@ -3,9 +3,10 @@ import re
 from datetime import datetime
 from functools import wraps
 from flask import request, jsonify, make_response
+from flask_cors import CORS
 from json import dumps
 from marshmallow_mongoengine import ModelSchema
-from flask_restful import Api, reqparse
+from flask_restful import Api, reqparse, inputs
 from flask_mongoengine import MongoEngine, DoesNotExist
 from flask_jwt_extended import get_jwt_identity
 from mongoengine.queryset.visitor import Q
@@ -17,11 +18,17 @@ from .exceptions import InvalidPayloadSupplied, BadRequest, Forbidden
 
 API_PREFIX = '/api'
 
+
 class QueryArgs:
     DAY = 'day'
     ORDER_BY = 'order_by'
     DESC = 'desc'
 
+    GREATER = 'gt'
+
+    URL = 'url'
+
+
 # Pagination
 DEFAULT_PAGE_SIZE = 10
 
@@ -33,6 +40,7 @@ mongo = MongoEngine()
 def create_module(app):
 
     mongo.init_app(app)
+    CORS(app)
 
     from .v1 import create_module as create_api_v1
 
@@ -51,9 +59,9 @@ def output_json(data, code, headers=None):
     """
         NOTE: if a resource method is decorated with 'paginated' this method is not called
     """
-    if isinstance(data, mongo.Document):
+    if isinstance(data, mongo.Document) or isinstance(data, mongo.EmbeddedDocument):
         data = data.to_mongo()
-    
+
     resp = make_response(jsonify(data), code)
     resp.headers.extend(headers or {})
     return resp
@@ -76,6 +84,7 @@ def validate_payload(model_schema: ModelSchema, kwname='payload'):
 
     return decorate
 
+
 def parse_query_args(func):
     query_args_reqparse = reqparse.RequestParser()
     query_args_reqparse.add_argument(
@@ -99,6 +108,20 @@ def parse_query_args(func):
         required=False,
         default=False
     )
+    query_args_reqparse.add_argument(
+        QueryArgs.GREATER,
+        type=str,
+        location=['args'],
+        required=False
+    )
+    query_args_reqparse.add_argument(
+        QueryArgs.URL,
+        type=inputs.regex(
+            "^(https?:\\/\\/(?:www\\.)?)?[-a-zA-Z0-9@:%._\\+~#=]{1,256}\\.[a-zA-Z0-9()]{1,6}\\b(?:[-a-zA-Z0-9()@:%_\\+.~#?&\\/=]*)$"),
+        location=['args'],
+        required=False
+    )
+
     @wraps(func)
     def wrapper(*args, **kwargs):
         query_args = query_args_reqparse.parse_args()
@@ -107,14 +130,14 @@ def parse_query_args(func):
             QueryArgs.DAY: query_args[QueryArgs.DAY],
             QueryArgs.ORDER_BY: query_args[QueryArgs.ORDER_BY],
             QueryArgs.DESC: query_args[QueryArgs.DESC],
-
+            QueryArgs.GREATER: query_args[QueryArgs.GREATER],
+            QueryArgs.URL: query_args[QueryArgs.URL],
         }
 
         return func(*args, **kwargs)
     return wrapper
 
 
-
 def get_payload(kwname='payload'):
     def decorate(func):
         @wraps(func)
@@ -160,6 +183,7 @@ def paginated(func):
         required=False,
         default=DEFAULT_PAGE_SIZE
     )
+
     @wraps(func)
     def wrapper(*args, **kwargs):
         page_args = pagination_reqparse.parse_args()
@@ -180,13 +204,14 @@ def paginated(func):
         page = func(*args, **kwargs)
 
         return jsonify({
-            #"results": page.items,
+            # "results": page.items,
             "results": [item.to_mongo() if isinstance(item, mongo.Document) else item for item in page.items],
             "pages": page.pages
         })
 
     return wrapper
 
+
 def _update_embedded_document(new_doc: mongo.EmbeddedDocument, old_doc: mongo.EmbeddedDocument, patch=True):
     if patch == True:
         for field in new_doc.__class__._fields:
@@ -196,6 +221,7 @@ def _update_embedded_document(new_doc: mongo.EmbeddedDocument, old_doc: mongo.Em
     else:
         return new_doc
 
+
 def _update_document(coll_class: mongo.Document.__class__, new_doc: mongo.Document, old_doc: mongo.Document, patch=True):
     # Remove generated id and link new doc with current owner
     new_doc._id = old_doc._id
@@ -203,10 +229,10 @@ def _update_document(coll_class: mongo.Document.__class__, new_doc: mongo.Docume
     new_doc.insert_timestamp = old_doc.insert_timestamp
 
     if patch == True:
-        return coll_class._get_collection().update(
+        return coll_class._get_collection().update_one(
             {'_id': old_doc.id}, {'$set': new_doc.to_mongo()})
     else:
-        return coll_class._get_collection().update(
+        return coll_class._get_collection().replace_one(
             {'_id': old_doc.id}, new_doc.to_mongo())
 
 
@@ -217,39 +243,56 @@ def put_document(coll_class: mongo.Document.__class__, new_doc: mongo.Document,
 def patch_document(coll_class: mongo.Document.__class__, new_doc: mongo.Document, old_doc: mongo.Document):
     return _update_document(coll_class, new_doc, old_doc, patch=True)
 
+
 def put_embedded_document(new_doc: mongo.EmbeddedDocument, old_doc: mongo.EmbeddedDocument):
     return _update_embedded_document(new_doc, old_doc, patch=False)
 
+
 def patch_embedded_document(new_doc: mongo.EmbeddedDocument, old_doc: mongo.EmbeddedDocument):
     return _update_embedded_document(new_doc, old_doc, patch=True)
 
 
 def _build_query_by_params(base_query, query_args):
     if QueryArgs.DAY in query_args and query_args[QueryArgs.DAY] is not None:
-        if bool(re.search('^[0-9]{4}-[0-1][0-9]-[0-3][0-9]$', query_args[QueryArgs.DAY])):
+        if bool(re.search(r'^[0-9]{4}-[0-1][0-9]-[0-3][0-9]$', query_args[QueryArgs.DAY])):
             try:
-                searched_day = datetime.strptime(query_args[QueryArgs.DAY], '%Y-%m-%d')
+                searched_day = datetime.strptime(
+                    query_args[QueryArgs.DAY], '%Y-%m-%d')
             except ValueError as ex:
-                raise BadRequest('invalid day parameter supplied: {}'.format(ex))
+                raise BadRequest(
+                    'invalid day parameter supplied: {}'.format(ex))
         else:
             raise BadRequest('invalid day format')
-        
+
         base_query = base_query & Q(date=searched_day)
-    
+
+    if QueryArgs.GREATER in query_args and query_args[QueryArgs.GREATER] is not None:
+        if (not bool(re.search(r'^\w+\$\d+$', query_args[QueryArgs.GREATER]))):
+            raise BadRequest('invalid gt value')
+
+        split = query_args[QueryArgs.GREATER].split('$')
+
+        base_query = base_query & Q(**{"{}__gt".format(split[0]): split[1]})
+
     return base_query
 
-def _apply_ordering(filtered_objects, query_args):
-    if(query_args[QueryArgs.ORDER_BY] != None and query_args[QueryArgs.ORDER_BY] != ''):
-        if(query_args[QueryArgs.DESC] == True):
-            filtered_objects = filtered_objects.order_by('-' + query_args[QueryArgs.ORDER_BY]) # descending "-"
-        else:
-            filtered_objects = filtered_objects.order_by('+' + query_args[QueryArgs.ORDER_BY]) # ascending "+"
 
-    return filtered_objects 
+def _apply_ordering(filtered_objects, query_args):
+    if (query_args[QueryArgs.ORDER_BY] != None and query_args[QueryArgs.ORDER_BY] != ''):
+        if (query_args[QueryArgs.DESC] == True):
+            filtered_objects = filtered_objects.order_by(
+                '-' + query_args[QueryArgs.ORDER_BY])  # descending "-"
+        else:
+            filtered_objects = filtered_objects.order_by(
+                '+' + query_args[QueryArgs.ORDER_BY])  # ascending "+"
+
+    return filtered_objects
+
 
 def _apply_pagination(ordered_objects, page_args):
     return ordered_objects.paginate(page=page_args['page'], per_page=page_args['per_page'])
 
+
 def search_on_model(coll_class: mongo.Document.__class__, base_query, query_args, page_args):
     query_filter = _build_query_by_params(base_query, query_args)
 
@@ -257,4 +300,4 @@ def search_on_model(coll_class: mongo.Document.__class__, base_query, query_args
     ordered_objects = _apply_ordering(filtered_objects, query_args)
     paginated_objects = _apply_pagination(ordered_objects, page_args)
 
-    return paginated_objects
\ No newline at end of file
+    return paginated_objects
