@@ -1,5 +1,8 @@
 from .. import mongo
 
+from .base_document import BaseDocument
+
+
 class Config(mongo.Document):
     min_version_code = mongo.IntField(unique=True, required=True)
     require_update = mongo.BooleanField(default=False)
@@ -7,8 +10,9 @@ class Config(mongo.Document):
     properties = mongo.DictField(default=dict())
 
     meta = {
-        'collection' : 'configs'
+        'collection': 'configs',
+        'strict': False
     }
 
     def __repr__(self):
-           return "<Config '{}'>".format(self.properties)
\ No newline at end of file
+        return "<Config '{}'>".format(self.properties)
